import { IconButton, InputAdornment, TextField } from '@material-ui/core';
import React, { FunctionComponent } from 'react';
import { DateRange, DateRangePicker } from '@material-ui/pickers';
import styles from 'EnhancedTable.module.scss';
import { getDatabaseFormatDate } from 'utils/moment';
import ClearIcon from '@material-ui/icons/Clear';

type Props = {
  filterValue: any;
  setFilter: (value: any) => void;
  title: string;
  valueKey?: string;
  labelKey?: string;
};

const DatetimePickerFilter: FunctionComponent<Props> = (props: Props) => {
  const { filterValue, setFilter } = props;

  const value: DateRange = [filterValue?.from || null, filterValue?.to || null];

  function clearInput(key: 'from' | 'to') {
    const remainKey = key === 'from' ? 'to' : 'from';
    const newFilter =
      filterValue && filterValue[remainKey]
        ? {
            ...filterValue,
            [key]: null,
          }
        : undefined;
    setFilter(newFilter);
  }

  return (
    <DateRangePicker
      startText={props.title + ' from'}
      endText={props.title + ' to'}
      value={value}
      mask="__/__/____"
      inputFormat={`MM/DD/YYYY`}
      onChange={([fromDate, toDate]) => {
        return setFilter({
          from: getDatabaseFormatDate(fromDate || ''),
          to: getDatabaseFormatDate(toDate || ''),
        });
      }}
      renderInput={(startProps, endProps) => (
        <div className="dflex">
          <TextField
            {...startProps}
            variant="standard"
            helperText={''}
            error={false}
            InputLabelProps={{
              shrink: true,
            }}
            className={styles.daterange}
            InputProps={{
              endAdornment: (
                <InputAdornment
                  className={styles.adornment}
                  position="end"
                  onClick={() => {
                    clearInput('from');
                  }}
                >
                  <IconButton
                    className={styles.clearBtn}
                    aria-label="toggle password visibility"
                    edge="end"
                  >
                    <ClearIcon style={{ fontSize: '12px' }} />
                  </IconButton>
                </InputAdornment>
              ),
            }}
          />
          <span className="invisible">::</span>
          <TextField
            {...endProps}
            helperText={''}
            variant="standard"
            error={false}
            InputLabelProps={{ shrink: true }}
            className={styles.daterange}
            InputProps={{
              endAdornment: (
                <InputAdornment
                  className={styles.adornment}
                  position="end"
                  onClick={() => {
                    clearInput('to');
                  }}
                >
                  <IconButton
                    className={styles.clearBtn}
                    aria-label="toggle password visibility"
                    edge="end"
                  >
                    <ClearIcon style={{ fontSize: '12px' }} />
                  </IconButton>
                </InputAdornment>
              ),
            }}
          />
        </div>
      )}
    />
  );
};

export default React.memo(DatetimePickerFilter);
