import React, { useState, useEffect } from 'react';
import { ColumnInstance } from 'react-table';
import { TextField } from '@material-ui/core';
import { useDebounce } from 'utils/customHook';

type Props = {
  column: ColumnInstance<any>;
  title?: string;
  type?: string;
};

function TextColumnFilter(props: Props) {
  const { filterValue, setFilter, Header, id } = props.column;
  const [value, setValue] = useState(filterValue || '');

  const debouncedSearchValue = useDebounce(value, 500);

  useEffect(
    () => {
      if (
        (!filterValue && debouncedSearchValue === '') ||
        filterValue === debouncedSearchValue
      )
        return;
      setFilter(debouncedSearchValue || undefined);
    },
    // eslint-disable-next-line react-hooks/exhaustive-deps
    [debouncedSearchValue]
  );

  useEffect(() => {
    !filterValue && value !== '' && setValue('');
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [filterValue]);

  return (
    <React.Fragment>
      <TextField
        fullWidth
        type={props.type}
        label={props.title || Header || id}
        InputLabelProps={{ shrink: true }}
        value={value}
        placeholder={'All'}
        onChange={(e) => {
          setValue(e.target.value);
        }}
      />
    </React.Fragment>
  );
}

export default TextColumnFilter;
