import React, { FunctionComponent } from 'react';
import styles from 'EnhancedTable.module.scss';
import { Tooltip } from '@material-ui/core';
import clsx from 'clsx';
import useCloseActionMenu from 'Toolbar/useCloseActionMenu';
import { MenuItem } from 'react-contextmenu';

type Props = {
  disabled?: boolean;
  title?: string;
  noWrapper?: boolean;
  closeOnClick?: boolean;
};

const TableActionItem: FunctionComponent<Props> = (props) => {
  const closeActionMenu = useCloseActionMenu();
  function render() {
    return (
      <div
        onClick={closeActionMenu}
        className={clsx(!props.noWrapper && styles.tab)}
      >
        {props.children}
      </div>
    );
  }
  return (
    <MenuItem className="no-focus">
      {props.disabled ? (
        <Tooltip
          className={styles.disableTab}
          onClickCapture={(event) => {
            event.preventDefault();
            event.stopPropagation();
            return;
          }}
          title={props.title ?? 'Please select some items in table'}
        >
          {render()}
        </Tooltip>
      ) : (
        render()
      )}
    </MenuItem>
  );
};

export default TableActionItem;
