import { TableInstance, useAsyncDebounce } from 'react-table';
import { useEffect } from 'react';
import { getFilters, getRouterQueries } from 'utils/router';
import { useHistory, useLocation } from 'react-router-dom';
import { TPageParams } from 'AppModels';
import config from 'config';
import qs from 'qs';

function useChangeLocationQuery(
  instance: TableInstance<any>,
  fetchData?: (payload: TPageParams) => void
) {
  const {
    setAllFilters,
    state: { pageIndex, pageSize, sortBy, filters },
  } = instance;

  const location = useLocation();
  const history = useHistory();

  useEffect(() => {
    const currentQuery = getFilters(location.search);
    setAllFilters(currentQuery);
  }, [location.search, setAllFilters]);

  const fetchDataDebounce = useAsyncDebounce(() => {
    const currentQuery = getRouterQueries(location.search);
    const query: TPageParams = {};

    if (Object.keys(filters).length) {
      query.filter = filters.reduce((obj: Record<string, any>, item) => {
        obj[item.id] = item.value;
        return obj;
      }, {});
    }

    if (Object.keys(sortBy).length) {
      query.sort = sortBy.reduce((obj: Record<string, any>, item) => {
        obj[item.id] = item.desc ? 'desc' : 'asc';
        return obj;
      }, {});
    }

    if (pageIndex) {
      query.page = pageIndex + 1;
    }

    if (pageSize !== config.perPage) query.per_page = pageSize;

    if (currentQuery.search && typeof currentQuery.search === 'string') {
      query.search = currentQuery.search;
    }

    const search = qs.stringify(query);
    const currentSearch = qs.stringify(currentQuery);

    if (search === currentSearch) {
      if (fetchData) {
        fetchData(query);
      }
      return;
    } else {
      history.push({
        search: search,
      });
    }
  }, 100);

  useEffect(() => {
    fetchDataDebounce();
  }, [pageIndex, pageSize, filters, sortBy, location, fetchDataDebounce]);
}
export default useChangeLocationQuery;
