import React, { FunctionComponent } from 'react';
import { TableOptions, useExpanded, useGroupBy, useTable } from 'react-table';
import MaUTable from '@material-ui/core/Table';
import { TableBody, TableCell, TableHead, TableRow } from '@material-ui/core';
import styles from './EnhancedTable.module.scss';
import clsx from 'clsx';
import KeyboardArrowDownIcon from '@material-ui/icons/KeyboardArrowDown';
import KeyboardArrowRightIcon from '@material-ui/icons/KeyboardArrowRight';

type Props = TableOptions<any> & {
  defaultGroupBy?: string;
};

const AggressionTable: FunctionComponent<Props> = (props) => {
  const { columns, data } = props;
  const {
    getTableProps,
    getTableBodyProps,
    headerGroups,
    rows,
    prepareRow,
  } = useTable(
    {
      columns,
      data,
      autoResetExpanded: false,
      initialState: {
        groupBy: [props.defaultGroupBy || ''],
      },
    },
    useGroupBy,
    useExpanded
  );
  return (
    <div className={clsx(styles.tableBodyScroll, styles.groupBy)}>
      <MaUTable {...getTableProps()}>
        <TableHead>
          {headerGroups.map((headerGroup, index) => (
            <TableRow {...headerGroup.getHeaderGroupProps()}>
              {headerGroup.headers.map((column, index) => {
                return (
                  <TableCell {...column.getHeaderProps()}>
                    <span className={styles.headerCell}>
                      <span>{column.render('Header')}</span>
                    </span>
                  </TableCell>
                );
              })}
            </TableRow>
          ))}
        </TableHead>
        <TableBody {...getTableBodyProps()}>
          {rows.map((row, i) => {
            prepareRow(row);
            return (
              <TableRow
                {...row.getRowProps()}
                className={clsx(row.isSelected && styles.selected)}
              >
                {row.cells.map((cell) => {
                  return (
                    <TableCell {...cell.getCellProps()}>
                      {cell.isGrouped ? (
                        // If it's a grouped cell, add an expander and row count
                        <span className={styles.headerCell}>
                          <span
                            className="dflex-center"
                            {...row.getToggleRowExpandedProps()}
                          >
                            {row.isExpanded ? (
                              <KeyboardArrowDownIcon />
                            ) : (
                              <KeyboardArrowRightIcon />
                            )}
                          </span>{' '}
                          <span>{cell.render('Cell')}</span>
                        </span>
                      ) : cell.isAggregated ? (
                        // If the cell is aggregated, use the Aggregated
                        // renderer for cell
                        cell.render('Aggregated')
                      ) : cell.isPlaceholder ? null : ( // For cells with repeated values, render null
                        // Otherwise, just render the regular cell
                        cell.render('Cell')
                      )}
                    </TableCell>
                  );
                })}
              </TableRow>
            );
          })}
        </TableBody>
      </MaUTable>
    </div>
  );
};

export default AggressionTable;
