import React, {
  FunctionComponent,
  useCallback,
  useEffect,
  useRef,
  useState,
} from 'react';
import MuiTheme from 'MuiTheme';
import TodayIcon from '@material-ui/icons/Today';
import AppTextField from 'TextField/AppTextField';
import { DatePicker, DateTimePickerProps } from '@material-ui/pickers';
import ClearIcon from '@material-ui/icons/Clear';
import { getDatabaseFormatDateTime, getDatabaseFormatType } from 'utils/moment';
import { IconButton } from '@material-ui/core';
import DoneRoundedIcon from '@material-ui/icons/DoneRounded';
import styles from './EditableCell.module.scss';
import tableStyles from '../EnhancedTable.module.scss';
import EditIcon from '@material-ui/icons/Edit';
import { useOnClickOutside } from 'utils/customHook';
import { useDispatch } from 'react-redux';
import { setTableSelectable } from 'store/actions';

type Props = Partial<DateTimePickerProps> & {
  row: any;
  column: any;
  value: any;
};

const EditableYear: FunctionComponent<Props> = (props) => {
  const dispatch = useDispatch();
  const setSelectable = useCallback(
    (value: boolean) => {
      dispatch(setTableSelectable(value));
    },
    [dispatch]
  );
  const { row, column, value } = props;

  const divEl = useRef<HTMLInputElement>(null);
  useOnClickOutside(divEl, () => cancelTimePicker());

  const [editDate, setEditDate] = useState<boolean>(false);
  const [selectedDate, setSelectedDate] = useState<Date | any>(value);

  function openTimePicker() {
    setEditDate(true);
    setSelectable(true);
  }

  function cancelTimePicker() {
    setSelectedDate(value);
    setEditDate(false);
  }

  useEffect(() => {
    setSelectedDate(value);
  }, [value]);

  function updateData() {
    if (column.editData) {
      column.editData(
        row.original,
        getDatabaseFormatType(selectedDate as string, 'YYYY'),
        column.id
      );
    }
    setEditDate(false);
  }

  return (
    <div className={styles.formEditableDateTime}>
      {!editDate ? (
        <span>
          {getDatabaseFormatType(selectedDate as string, 'YYYY')}
          <IconButton
            className={tableStyles.displayOnHover}
            size="small"
            onClick={openTimePicker}
          >
            <EditIcon color="primary" fontSize="small" />
          </IconButton>
        </span>
      ) : (
        <DatePicker
          value={selectedDate}
          onChange={(newVal) => {
            setSelectedDate(getDatabaseFormatDateTime(newVal as string));
          }}
          views={['year']}
          desktopModeMediaQuery={MuiTheme.breakpoints.up('sm')}
          openPickerIcon={<TodayIcon color={'secondary'} />}
          mask={'____'}
          inputFormat={'YYYY'}
          clearable={true}
          renderInput={(props) => {
            return (
              <AppTextField
                {...props}
                InputLabelProps={{ shrink: true }}
                InputProps={{
                  ...props.InputProps,
                  inputProps: {
                    ...(props?.inputProps || {}),
                    disabled: true,
                  },
                  endAdornment: (
                    <div className={styles.formButton}>
                      {props.InputProps?.endAdornment}
                      <IconButton size="small" onClick={updateData}>
                        <DoneRoundedIcon color="primary" fontSize="small" />
                      </IconButton>
                      <IconButton
                        size="small"
                        onClick={() => cancelTimePicker()}
                      >
                        <ClearIcon color="primary" fontSize="small" />
                      </IconButton>
                    </div>
                  ),
                }}
                helperText={false}
              />
            );
          }}
        />
      )}
    </div>
  );
};

export default EditableYear;
