import { ColumnInstance } from 'react-table';
import React from 'react';
import AppAutocomplete from 'components/Autocomplete/AppAutocomplete';

type Props = {
  column: ColumnInstance<any>;
  options: Array<any>;
  title?: string;
  valueKey?: string;
  labelKey?: string;
};

function SelectColumnAutoFilter({
  column,
  options,
  title,
  valueKey = 'id',
  labelKey = 'name',
}: Props) {
  const { filterValue, setFilter, Header, id } = column;
  const label = title || Header || id;

  const currentValue = options.find(
    (option) => option[valueKey] === filterValue
  );
  return (
    <AppAutocomplete
      options={options}
      value={currentValue}
      onChange={(event, newValue) => {
        if (typeof newValue === 'object' && !Array.isArray(newValue)) {
          setFilter(newValue?.[valueKey] || undefined);
        }
      }}
      labelKey={labelKey}
      textField={{
        variant: 'standard',
        label: label,
        InputLabelProps: { shrink: true },
        placeholder: 'ALL',
      }}
    />
  );
}

export default SelectColumnAutoFilter;
