import React, { Fragment } from 'react';
import Toolbar from '@material-ui/core/Toolbar';
import { TableInstance } from 'react-table';
import styles from 'EnhancedTable.module.scss';
import ColumnDisplay from 'Toolbar/ColumnDisplay';
import FilterBox from 'Toolbar/FilterBox';
import GlobalFilter from 'Toolbar/GlobalFilter';
import LocalGlobalFilter from 'Toolbar/LocalGlobalFilter';

type Props = {
  toolbarItems?: React.ReactElement;
  instance: TableInstance<any>;
  stableColumns: Array<string>;
  pagination: React.ReactElement;
  isLocal?: boolean;
  hasGlobalSearch?: boolean;
  width: number;
  defaultHiddenColumns?: string[];
};

const TableToolbar = (props: Props) => {
  const {
    isLocal = false,
    hasGlobalSearch = true,
    defaultHiddenColumns,
  } = props;
  const selectedRowNumber = props.instance.selectedFlatRows.length;
  return (
    <Toolbar className={styles.toolbar} style={{ width: props.width }}>
      <Fragment>
        <div className={styles.actionBox}>
          {props.toolbarItems}
          <FilterBox
            instance={props.instance}
            stableColumns={props.stableColumns}
          />
          <ColumnDisplay
            instance={props.instance}
            stableColumns={props.stableColumns}
            defaultHiddenColumns={defaultHiddenColumns}
          />
          {hasGlobalSearch && isLocal && (
            <LocalGlobalFilter
              globalFilter={props.instance.state.globalFilter}
              setGlobalFilter={props.instance.setGlobalFilter}
            />
          )}
          {hasGlobalSearch && !isLocal && <GlobalFilter />}
          {selectedRowNumber > 0 && (
            <div className={styles.infoText}>
              {selectedRowNumber} Selected Rows
            </div>
          )}
        </div>
        {props.pagination}
      </Fragment>
    </Toolbar>
  );
};

export default React.memo(TableToolbar);
