import dayjs, { ConfigType, OpUnitType } from 'dayjs';
import relativeTime from 'dayjs/plugin/relativeTime';
import updateLocale from 'dayjs/plugin/updateLocale';
import utc from 'dayjs/plugin/utc';

dayjs.extend(relativeTime);
dayjs.extend(updateLocale);
dayjs.extend(utc);

dayjs.updateLocale('en', {
  relativeTime: {
    s: '1 few seconds',
    ss: '%d seconds',
    m: '1 minute',
    mm: '%d minutes',
    h: '1 hour',
    hh: '%d hours',
    d: '1 day',
    dd: '%d days',
    w: '1 week',
    M: '1 month',
    MM: '%d months',
    y: '1 year',
    yy: '%d years',
  },
});
export function getDate(date?: ConfigType) {
  return date ? dayjs(date).format('MM/DD/YYYY') : null;
}

export function getDateFromUTC(date?: ConfigType) {
  return date ? dayjs.utc(date).local().format('MM/DD/YYYY') : null;
}

export function getDateTimeForTextField(date?: ConfigType): string {
  return dayjs(date).format('YYYY-MM-DD[T]HH:mm');
}

export function getDateTimeForTextFieldUTC(date?: ConfigType): string {
  return dayjs.utc(date).format('YYYY-MM-DD HH:mm:ss');
}

export function getDateForTextField(date?: ConfigType): string {
  return dayjs(date).format('YYYY-MM-DD');
}

export function getDateType(date?: ConfigType): string {
  return dayjs(date).format('MM/DD/YYYY');
}

export function getYearTextField(date?: ConfigType): string {
  return dayjs(date).format('YYYY');
}

export function getDatabaseFormatDate(date?: ConfigType) {
  return date ? dayjs(date).format('YYYY-MM-DD') : null;
}

export function getDatabaseFormatDateTime(date?: ConfigType) {
  return dayjs(date).format('YYYY-MM-DD HH:mm:ss');
}

export function getDatabaseFormatDateTimeInUTC(date?: ConfigType) {
  return date ? dayjs.utc(date).format('YYYY-MM-DD HH:mm:ss') : null;
}

export function getDatabaseFormatDateTimeInLocal(date?: ConfigType) {
  return date ? dayjs.utc(date).local().format('YYYY-MM-DD HH:mm:ss') : null;
}

export function getDatabaseFormatType(date?: ConfigType, type?: string) {
  return dayjs(date).format(type);
}

export function getDateTime(date?: ConfigType) {
  return date ? dayjs(date).format('MM/DD/YYYY HH:mm') : null;
}

export function getDiffTime(date?: ConfigType) {
  return dayjs(date).fromNow(true);
}

export function getDateFromAddedDuration(
  config: {
    duration: number;
    unit: OpUnitType;
  },
  date?: ConfigType
) {
  return dayjs(date).add(config.duration, config.unit).format('YYYY-MM-DD');
}

export function isStringISOTimestamp(date: string) {
  const regExp = new RegExp(
    '^(-?(?:[1-9][0-9]*)?[0-9]{4})-(1[0-2]|0[1-9])-(3[01]|0[1-9]|[12][0-9])T(2[0-3]|[01][0-9]):([0-5][0-9]):([0-5][0-9])(.[0-9]+)?(Z)?$'
  );
  return regExp.test(date);
}

export function getDiffDay(date?: ConfigType) {
  const diffDay = dayjs().diff(dayjs(date), 'day') + 1;
  return Math.abs(diffDay) > 1 ? `${diffDay} days` : `${diffDay} day`;
}
